@@ -1,8 +1,6 @@
 package Search::Sitemap;
-$Search::Sitemap::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 use Search::Sitemap::Types qw(
@@ -15,7 +13,6 @@ use XML::Twig;
 use IO::File;
 use Carp qw( carp croak );
 use HTML::Entities qw( decode_entities );
-use Class::Load;
 use namespace::clean -except => 'meta';
 
 has 'urls'  => (
@@ -23,7 +20,7 @@ has 'urls'  => (
     isa     => SitemapUrlStore,
     coerce  => 1,
     default => sub {
-        Class::Load::load_class( 'Search::Sitemap::URLStore::Memory' );
+        Class::MOP::load_class( 'Search::Sitemap::URLStore::Memory' );
         return Search::Sitemap::URLStore::Memory->new;
     },
     handles => {
@@ -43,13 +40,13 @@ has 'pretty'    => (
 
 class_has 'base_element'    => (
     is          => 'rw',
-    isa         => Str,
+    isa         => 'Str',
     default     => 'urlset'
 );
 
 has 'xmlparser' => (
     is      => 'rw',
-    isa     => 'XML::Twig',
+    isa     => CodeRef,
     lazy    => 1,
     default => sub {
         my $self = shift;
@@ -58,17 +55,17 @@ has 'xmlparser' => (
             twig_roots  => {
                 $self->base_element => sub {
                     my ( $twig, $elt ) = @_;
+                    my %url = ();
                     foreach my $c ( $elt->children ) {
-                        my %url = ();
                         my $var = $c->gi;
-                        croak "Unrecognised element $var"
-                            unless $var =~ /^(?:url|sitemap)$/;
-                        foreach my $e ( $c->children ) {
-                            $url{ $e->gi } = decode_entities( $e->text );
+                        if ( $var eq 'loc' ) {
+                            $url{ $var } = decode_entities( $c->text );
+                        } else {
+                            $url{ $var } = $c->text;
                         }
-                        $self->update( \%url );
                     }
                     $twig->purge;
+                    $self->update( \%url );
                 },
             },
         );
@@ -82,7 +79,7 @@ has 'have_zlib' => (
     lazy    => 1,
     default => sub {
         local $@;
-        eval { Class::Load::load_class( 'IO::Zlib' ) };
+        eval { Class::MOP::load_class( 'IO::Zlib' ) };
         return $@ ? 0 : 1;
     },
 );
@@ -95,16 +92,15 @@ sub _build_xml_headers {
     my $ext = $self->extensions;
     return {
         'xmlns:xsi' => 'http://www.w3.org/2001/XMLSchema-instance',
-        'xsi:schemaLocation' => join( ' ',
-            'http://www.sitemaps.org/schemas/sitemap/0.9',
-            'http://www.sitemaps.org/schemas/sitemap/0.9/sitemap.xsd',
-        ),
+        'xsi:schemaLocation' => 'http://www.sitemaps.org/schemas/sitemap/0.9',
+        'url' => 'http://www.sitemaps.org/schemas/sitemap/0.9/sitemap.xsd',
         'xmlns' => 'http://www.sitemaps.org/schemas/sitemap/0.9',
         ( map { ( "xmlns:$_" => $ext->{ $_ } ) } keys %{ $ext } ),
     }
 }
 
-sub xml {
+has 'xml'   => ( is => 'ro', isa => Str, lazy_build  => 1 );
+sub _build_xml {
     my $self = shift;
 
     my $xml = XML::Twig::Elt->new(
@@ -119,7 +115,7 @@ sub xml {
     return $header.$xml->sprint();
 }
 
-class_has 'url_type'    => ( is => 'rw', isa => Str, default => 'url' );
+class_has 'url_type'    => ( is => 'rw', isa => 'Str', default => 'url' );
 class_has 'url_fields'  => (
     is          => 'rw',
     isa         => ArrayRef[Str],
@@ -217,8 +213,6 @@ __PACKAGE__->meta->make_immutable;
 1;
 __END__
 
-=encoding utf-8
-
 =head1 NAME
 
 Search::Sitemap - Perl extension for managing Search Engine Sitemaps
@@ -258,6 +252,8 @@ such as when they were last modified, how frequently they change, etc.
 
 This module allows you to create and modify sitemaps.
 
+=head1 ATTRIBUTES
+
 =head1 METHODS
 
 =head2 new()
@@ -278,11 +274,7 @@ automatically if the filename ends with .gz.
 
 =head2 urls()
 
-Return the L<Search::Sitemap::URLStore> object that make up the sitemap.
-
-To get all urls (L<Search::Sitemap::URL> objects) please use:
-
-    my @urls = $map->urls->all;
+Return the L<Search::Sitemap::URL> objects that make up the sitemap.
 
 =head2 add( $item, [$item...] )
 
@@ -386,9 +378,12 @@ false value means 'none'.
 Returns the value it was set to, or the current value if called with no
 arguments.
 
-=head1 ACKNOWLEDGEMENTS
+=head1 MODULE HOME PAGE
 
-Thanks to Alex J. G. Burzyński for help with maintaining this module.
+The home page of this module is
+L<http://www.jasonkohles.com/software/Search-Sitemap>.  This is where you can
+always find the latest version, development versions, and bug reports.  You
+will also find a link there to report bugs.
 
 =head1 SEE ALSO
 
@@ -398,6 +393,8 @@ L<Search::Sitemap::Ping>
 
 L<Search::Sitemap::Robot>
 
+L<http://www.jasonkohles.com/software/Search-Sitemap>
+
 L<http://www.sitemaps.org/>
 
 =head1 AUTHOR
