@@ -1,8 +1,6 @@
 package Search::Sitemap::Index;
-$Search::Sitemap::Index::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 extends 'Search::Sitemap';
@@ -11,14 +9,14 @@ use MooseX::Types::Moose qw( ArrayRef );
 use Search::Sitemap::Types qw( SitemapURL XMLPrettyPrintValue );
 use namespace::clean -except => 'meta';
 
-class_has '+base_element' => ( default => 'sitemapindex' );
+class_has '+base_element' => ( default => 'siteindex' );
 class_has '+url_type'   => ( default => 'sitemap' );
 class_has '+url_fields' => ( default => sub { [qw( loc lastmod )] } );
 
 around '_build_xml_headers' => sub {
     my $next = shift;
     my $headers = $next->( @_ );
-    $headers->{ 'xsi:schemaLocation' } =~ s/sitemap\.xsd$/siteindex.xsd/;
+    $headers->{ 'url' } =~ s/sitemap\.xsd$/siteindex.xsd/;
     return $headers;
 };
 
@@ -28,21 +26,18 @@ __END__
 
 =head1 NAME
 
-Search::Sitemap::Index - Perl extension for managing Sitemap Indexes
+Search::SiteMap::Index - Perl extension for managing SiteMap Indexes
 
 =head1 SYNOPSIS
 
-  use Search::Sitemap::Index;
+  use Search:SiteMap::Index;
   
-  my $index = Search::Sitemap::Index->new();
-  $index->read( 'sitemap-index.gz' );
+  my $index = Search::SiteMap::Index->new( file => 'sitemap-index.gz' );
   
-  $index->add( Search::Sitemap::URL->new(
+  $index->add( Search::SiteMap::URL->new(
     loc     => 'http://www.jasonkohles.com/sitemap1.gz',
     lastmod => '2005-11-01',
   ) );
-
-  $index->write( 'sitemap-index.gz' );
   
 =head1 DESCRIPTION
 
@@ -53,6 +48,12 @@ more than one of them.
 
 L<Search::Sitemap::Index> inherits all the methods found in L<Search::Sitemap>.
 
+=head1 MODULE HOME PAGE
+
+The home page of this module is
+L<http://www.jasonkohles.com/software/Search-Sitemap>.  This is where you can
+always find the latest version, development versions, and bug reports.  You
+will also find a link there to report bugs.
 
 =head1 SEE ALSO
 
@@ -60,6 +61,8 @@ L<Search::Sitemap>
 
 L<Search::Sitemap::Ping>
 
+L<http://www.jasonkohles.com/software/Search-Sitemap>
+
 L<http://www.sitemaps.org/>
 
 =head1 AUTHOR
