@@ -1,8 +1,6 @@
 package Search::Sitemap::Ping;
-$Search::Sitemap::Ping::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 use Search::Sitemap::Pinger;
@@ -11,12 +9,11 @@ use Class::Trigger qw(
     before_submit after_submit
     before_engine after_engine
 );
-use MooseX::Types::Moose qw( ArrayRef );
 use namespace::clean -except => [qw( meta add_trigger call_trigger )];
 
 has 'urls'  => (
     is          => 'rw',
-    isa         => ArrayRef,
+    isa         => 'ArrayRef',
     lazy        => 1,
     auto_deref  => 1,
     default     => sub { [] },
@@ -24,7 +21,7 @@ has 'urls'  => (
 
 has 'engines'   => (
     is          => 'rw',
-    isa         => ArrayRef['Search::Sitemap::Pinger'],
+    isa         => 'ArrayRef[Search::Sitemap::Pinger]',
     auto_deref  => 1,
     lazy        => 1,
     default     => sub { [
@@ -166,6 +163,12 @@ In case of an error, the error string will be provided as the status.
 
 =back
 
+=head1 MODULE HOME PAGE
+
+The home page of this module is
+L<http://www.jasonkohles.com/software/Search-Sitemap>.  This is where you
+can always find the latest version, development versions, and bug reports.  You
+will also find a link there to report bugs.
 
 =head1 SEE ALSO
 
