@@ -1,8 +1,6 @@
 package Search::Sitemap::Pinger;
-$Search::Sitemap::Pinger::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 use LWP::UserAgent;
@@ -10,6 +8,7 @@ use MooseX::Types::Moose qw( ArrayRef Str HashRef );
 use MooseX::Types::URI qw( Uri );
 use URI;
 use Module::Find qw( usesub );
+use Moose::Util::TypeConstraints;
 use Class::Trigger qw(
     before_submit after_submit
     before_submit_url after_submit_url
@@ -17,6 +16,12 @@ use Class::Trigger qw(
 );
 use namespace::clean -except => [qw( meta add_trigger call_trigger )];
 
+coerce( __PACKAGE__, from 'Str', via {
+    my $class = join( '::', __PACKAGE__, $_ );
+    Class::MOP::load_class( $class );
+    return $class->new;
+} );
+
 sub ALL_PINGERS { grep { $_ ne __PACKAGE__ } usesub( __PACKAGE__ ) }
 
 has 'user_agent'    => (
