@@ -1,8 +1,6 @@
 package Search::Sitemap::Pinger::Ask;
-$Search::Sitemap::Pinger::Ask::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 extends 'Search::Sitemap::Pinger';
@@ -45,6 +43,7 @@ L<http://about.ask.com/en/docs/about/webmasters.shtml#22>
 
 Jason Kohles, E<lt>email@jasonkohles.comE<gt>
 
+L<http://www.jasonkohles.com/>
 
 =head1 COPYRIGHT AND LICENSE
 
