@@ -1,8 +1,6 @@
 package Search::Sitemap::Pinger::Google;
-$Search::Sitemap::Pinger::Google::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 extends 'Search::Sitemap::Pinger';
@@ -45,6 +43,8 @@ L<http://www.google.com/support/webmasters/bin/answer.py?answer=34609>
 
 Jason Kohles, E<lt>email@jasonkohles.comE<gt>
 
+L<http://www.jasonkohles.com/>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2005-2009 by Jason Kohles
