@@ -1,37 +1,28 @@
 package Search::Sitemap::Types;
-$Search::Sitemap::Types::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
-
-use Class::Load;
 use MooseX::Types -declare => [qw(
     SitemapURL SitemapUrlStore SitemapChangeFreq SitemapLastMod SitemapPriority
-    XMLPrettyPrintValue XMLTwig SitemapPinger
+    XMLPrettyPrintValue
 )];
 use MooseX::Types::Moose qw( Object HashRef Str Int Bool Num );
 use MooseX::Types::URI qw( Uri );
 use POSIX qw( strftime );
 
-class_type( 'Search::Sitemap::URL' );
-subtype SitemapURL, as 'Search::Sitemap::URL';
+subtype SitemapURL, as Object, where {
+    $_->isa( 'Search::Sitemap::URL' );
+};
 
 coerce SitemapURL,
-    from HashRef, via {
-        Class::Load::load_class( 'Search::Sitemap::URL' );
-        Search::Sitemap::URL->new( $_ );
-    },
-    from Str, via {
-        Class::Load::load_class( 'Search::Sitemap::URL' );
-        Search::Sitemap::URL->new( loc => $_ );
-    };
+    from HashRef, via { Search::Sitemap::URL->new( $_ ) },
+    from Str, via { Search::Sitemap::URL->new( loc => $_ ) };
 
 subtype XMLPrettyPrintValue, as Str, where {
-    $_ =~ m{ ^ (
+    $_ =~ m{
         none | nsgmls | nice | indented | indented_c | indented_a | cvs |
         wrapped | record | record_c
-    ) $ }x;
+    }x;
 };
 
 coerce XMLPrettyPrintValue,
@@ -53,78 +44,81 @@ coerce SitemapChangeFreq, from Str, via {
         y => 'yearly',
         n => 'never',
     );
-    if ( m{ ^( [ahdwmyn] ) }ix ) { return $types{ lc $1 } }
+    if ( m{([ahdwmyn])}i ) { return $types{ lc $1 } }
     return;
 };
 
-my $lastmod_re = qr/ ^
-    (\d{4})                 # year
-        \-?
-    (\d{2})?                # month
-        \-?
-    (\d{2})?                # day
-    (?:
-        T
-        (\d{2})             # hours
-        :
-        (\d{2})             # minutes
-        (?:
-            :(\d{2})        # seconds
-            (?:
-                \.(\d+)     # fraction of second
-            )?
-        )?
-        (?:
-            (Z|[\+\-]?\d{2}:\d{2}) # time zone
-        )?
-    )?
-$ /xi;
-
-subtype SitemapLastMod, as Str, where { /$lastmod_re/ };
+subtype SitemapLastMod, as 'Str', where {
+    /^\d\d\d\d-\d\d-\d\d(T\d\d:\d\d:\d\d\+\d\d?:\d\d)?$/
+};
 
 class_type 'DateTime';
 class_type 'HTTP::Response';
 class_type 'File::stat';
 class_type 'Path::Class::File';
 
+my $lastmod_re = qr/ ^
+    (\d\d\d\d-\d\d-\d\d)    # date
+    (?:                     # time portion is optional
+        [T\s]               # T or ' '
+        (\d\d:\d\d)(:\d\d)? # time, with optional seconds
+        (Z|\+\d\d?)(:\d\d)? # timezone offset, with optional seconds
+    )?
+$ /xi;
+
 coerce SitemapLastMod,
     from Str, via {
-        if ( $_ eq 'now' ) {
-            return strftime( "%Y-%m-%dT%H:%M:%S+00:00", gmtime( time ) );
+        if ( /$lastmod_re/ ) {
+            my ( $date, $time, $sec, $tzoff, $tzsec ) = ( $1, $2, $3, $4, $5 );
+
+            return $date unless $time;
+
+            $time .= $sec || ':00';
+
+            if ( defined $tzsec ) { $tzoff .= $tzsec }
+
+            if ( $tzoff =~ /^([+-])?(\d\d):?(\d\d)/ ) {
+                $tzoff = sprintf( '%s%02d:%02d', $1 || '+', $2, $3 || 0 );
+            } else {
+                $tzoff = '+00:00';
+            }
+            return $date.'T'.$time.$tzoff;
+        } elsif ( $_ eq 'now' ) {
+            return strftime( "%Y-%m-%dT%T+00:00", gmtime( time ) );
         } elsif ( $_ =~ /^\d+$/ ) {
-            return strftime( "%Y-%m-%dT%H:%M:%S+00:00", gmtime( $_ ) );
+            return strftime( "%Y-%m-%dT%T+00:00", gmtime( $_ ) );
+        } else {
+            die "Unknown string value '$_'";
         }
-        return $_;
     },
     from Num, via {
-        return strftime( "%Y-%m-%dT%H:%M:%S+00:00", gmtime( $_ ) );
+        return strftime( "%Y-%m-%dT%T+00:00", gmtime( $_ ) );
     },
     from 'DateTime', via {
-        my ( $datetime, $tzoff ) = $_->strftime("%Y-%m-%dT%H:%M:%S","%z");
-        if ( $tzoff =~ /^([+\-])?(\d\d):?(\d\d)/ ) {
+        my ( $date, $tzoff ) = $_->strftime("%Y-%m-%dT%T","%z");
+        if ( $tzoff =~ /^([+-])?(\d\d):?(\d\d)/ ) {
             $tzoff = sprintf( '%s%02d:%02d', $1 || '+', $2, $3 || 0 );
         } else {
             $tzoff = '+00:00';
         }
-        return $datetime.$tzoff;
+        return $date.$tzoff;
     },
     from 'HTTP::Response', via {
         my $modtime = $_->last_modified || ( time - $_->current_age );
-        return strftime( "%Y-%m-%dT%H:%M:%S+00:00", gmtime( $modtime ) );
+        return strftime( "%Y-%m-%dT%T+00:00", gmtime( $modtime ) );
     },
     from 'File::stat', via {
-        return strftime( "%Y-%m-%dT%H:%M:%S+00:00", gmtime( $_->mtime ) );
+        return strftime( "%Y-%m-%dT%T+00:00", gmtime( $_->mtime ) );
     },
     from 'Path::Class::File', via {
-        return strftime( "%Y-%m-%dT%H:%M:%S+00:00", gmtime( $_->stat->mtime ) );
+        return strftime( "%Y-%m-%dT%T+00:00", gmtime( $_->stat->mtime ) );
     };
 
 subtype SitemapPriority, as Num, where { $_ >= 0 && $_ <= 1 };
-coerce SitemapPriority,
-    from Num, via { $_ };
 
-class_type( 'Search::Sitemap::URLStore' );
-subtype SitemapUrlStore, as 'Search::Sitemap::URLStore';
+subtype SitemapUrlStore, as Object, where {
+    $_->isa( 'Search::Sitemap::URLStore' );
+};
 
 coerce SitemapUrlStore,
     from HashRef, via {
@@ -132,28 +126,16 @@ coerce SitemapUrlStore,
         my $class = $type =~ /::/
             ? $type
             : 'Search::Sitemap::URLStore::'.$type;
-        Class::Load::load_class( $class );
+        Class::MOP::load_class( $class );
         $class->new( $_ )
     },
     from Str, via {
         my $class = 'Search::Sitemap::URLStore::'.$_;
-        Class::Load::load_class( $class );
+        Class::MOP::load_class( $class );
         return $class->new;
     };
 
-class_type( 'XML::Twig' );
-
-class_type( 'Search::Sitemap::Pinger' );
-
-subtype SitemapPinger, as 'Search::Sitemap::Pinger';
-coerce SitemapPinger, from Str, via {
-    my $class = 'Search::Sitemap::Pinger::'.$_;
-    Class::Load::load_class( $class );
-    return $class->new;
-};
-
-class_type( 'LWP::UserAgent' );
-
+__PACKAGE__->meta->make_immutable;
 1;
 __END__
 
