@@ -1,8 +1,6 @@
 package Search::Sitemap::URL;
-$Search::Sitemap::URL::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 use MooseX::ClassAttribute;
@@ -24,7 +22,7 @@ class_has 'encode_entities'   => (
 
 class_has 'lenient'           => (
     is      => 'rw',
-    isa     => Bool,
+    isa     => 'Bool',
 );
 
 has 'loc'           => (
@@ -39,7 +37,7 @@ has 'changefreq'    => (
     isa         => SitemapChangeFreq,
     coerce      => 1,
     predicate   => 'has_changefreq',
-    clearer     => 'clear_changefreq',
+    clearer     => 'clear_lastmod',
 );
 has 'lastmod'       => (
     is          => 'rw',
@@ -57,7 +55,7 @@ has 'priority'      => (
 );
 has 'mobile'        => (
     is          => 'rw',
-    isa         => Bool,
+    isa         => 'Bool',
     predicate   => 'has_mobile',
     clearer     => 'clear_mobile',
 );
@@ -86,9 +84,6 @@ sub as_elt {
 
     my @elements = ();
     for my $f ( @fields ) {
-        my $exists = $self->can( "has_$f" );
-        next if $exists and not $self->$exists;
-
         my $method = '_'.$f.'_as_elt';
         my $val;
         if ( $self->can( $method ) ) {
@@ -220,6 +215,12 @@ Returns this URL and it's associated data as an L<XML::Twig::Elt> object.
 This is primarily an internal use method, you probably don't need to mess
 with it.
 
+=head1 MODULE HOME PAGE
+
+The home page of this module is
+L<http://www.jasonkohles.com/software/search-sitemap>.  This is where you
+can always find the latest version, development versions, and bug reports.  You
+will also find a link there to report bugs.
 
 =head1 SEE ALSO
 
@@ -229,6 +230,8 @@ L<Search::Sitemap::Index>
 
 L<Search::Sitemap::Ping>
 
+L<http://www.jasonkohles.com/software/search-sitemap/>
+
 L<http://www.sitemaps.org/>
 
 L<http://www.google.com/support/webmasters/bin/answer.py?answer=34648>
