@@ -1,8 +1,6 @@
 package Search::Sitemap::URLStore;
-$Search::Sitemap::URLStore::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 use Class::Trigger;
