@@ -1,16 +1,13 @@
 package Search::Sitemap::URLStore::Memory;
-$Search::Sitemap::URLStore::Memory::VERSION = '2.13_01';
-use 5.008003;
-use strict;
-use warnings;
+use strict; use warnings;
+our $VERSION = '2.02';
 our $AUTHORITY = 'cpan:JASONK';
 use Moose;
 extends 'Search::Sitemap::URLStore';
-use MooseX::Types::Moose qw( HashRef );
 use Class::Trigger;
 use namespace::clean -except => 'meta';
 
-has 'storage'   => ( is => 'ro', isa => HashRef, default => sub { {} } );
+has 'storage'   => ( is => 'ro', isa => 'HashRef', default => sub { {} } );
 
 sub get {
     my ( $self, $url ) = @_;
@@ -19,10 +16,8 @@ sub get {
 
 sub put {
     my $self = shift;
-
-    $self->storage->{ $_->loc } = $_ for @_;
-
-    return 1;
+    my $storage = $self->storage;
+    for my $obj ( @_ ) { $self->storage->{ $obj->loc } = $obj }
 }
 
 sub all { return values %{ shift->storage } }
